package com.vandyo.sentry.core;

import cn.hutool.json.JSONUtil;
import com.vandyo.sentry.core.cases.*;
import com.vandyo.sentry.core.collectionMachine.CollectionDealer;
import com.vandyo.sentry.core.collectionMachine.CollectionMachine;
import com.vandyo.sentry.core.collectionMachine.EmailDealer;
import com.vandyo.sentry.core.config.CheckMetaConfig;
import com.vandyo.sentry.core.dto.ErrStatus;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Component
public class Tmp {
    private static final Logger log = LoggerFactory.getLogger(Tmp.class);
    private static Integer times = 0;

    @Value("${vandyo.sid}")
    private String sId;
    @Value("${vandyo.uid}")
    private String uid;
    @Value("${vandyo.mobile}")
    public String mobile;
    @Value("${vandyo.pwd}")
    public String pwd;

    @Autowired
    private CheckMetaConfig checkMetaConfig;
    @Autowired
    private EmailDealer emailDealer;

    @Scheduled(fixedRate = 1000*30)
    public void test() {
        log.info("we run it {} times", ++times);
        Case case1 = null;
        // 上线前使用这段代码
        // 登录
        case1 = new LoginCase(mobile, pwd);
        // 获取消息接口
        case1 = new MsgGetDecorator(case1);
        // 查询用户信息
        case1 = new UserInfoDecorator(case1);
        case1 = new CarListDecorator(case1);
        // 获取车的日志
        case1 = new DayReportDecorator(case1);
        // 查询车轨迹接口
        case1 = new CarLocusPageDecorator(case1);
        // 查询车轨迹点 接口
        case1 = new CarLocausPointListDecorator(case1);
        // 查询车轨迹统计数据
        case1 = new CarLocusStatisticsDecorator(case1);
        // 轨迹行驶行为接口
        case1 = new CarLocusEventDecorator(case1);

        case1 = new CarInfoDecorator(case1);
        case1 = new CarDetectDecorator(case1);
        case1 = new CarStatusDecorator(case1);

        // 退出登录
        case1 = new LogoutDecorator(case1);
        case1.check();


        // banner接口
        Case case2 = null;
        case2 = new EmptyCase(sId,uid);
        case2 = new BannerListDecorator(case2);
        // 获取商品列表
        case2 = new MallGoodsDecorator(case2);
        case2.check();

        log.info("over!");
    }

    @Scheduled(fixedRate = 1000*60*5)
    public void check() {
        Map<String, Map<ErrStatus, Long>> data = CollectionMachine.checkRule(5);
        String info = JSONUtil.parseFromMap(data).toStringPretty();
        // 查看是否 符合规则 Using timeMap
        Map<String,Integer> timeMap = checkMetaConfig.getTimeMap();
        log.info("start to check rule！");
        List<CollectionDealer> list = new ArrayList<>(1);
        list.add(emailDealer);
        // FIXME: 添加其他处理
        CollectionMachine.checkTimes(timeMap,data,list);
    }
}
